pub struct SourceFile {
pub name: String,
pub abs_path: Option<PathBuf>,
pub rel_path: Option<PathBuf>,
pub source: String,
pub id: u8,
}Expand description
Represents a single KASM source file and associated data
Fields
name: StringThe name of the source file. No path, only the form of: filename.ext
abs_path: Option<PathBuf>The absolute path of this source file in the file system
rel_path: Option<PathBuf>The relative path of this source file to the place it was invoked
source: StringThe actual source code of the file
id: u8Each source file will be given a unique ID to be referred by inside of tokens
Implementations